/*
 * Copyright 2006 Sean Owen
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.planetj.servlet.filter.compression;

import org.jetbrains.annotations.NotNull;

import java.util.Enumeration;
import java.util.NoSuchElementException;

/**
 * <p>An {@link Enumeration} which enumerates nothing.</p>
 *
 * @author Sean Owen
 * @since 1.6
 */
final class EmptyEnumeration implements Enumeration {

	private static final Enumeration instance = new EmptyEnumeration();

	private EmptyEnumeration() {
		// do nothing
	}

	public static Enumeration getInstance() {
		return instance;
	}

	/**
	 * @return false always
	 */
	public boolean hasMoreElements() {
		return false;
	}

	/**
	 * @throws NoSuchElementException always
	 */
	public Object nextElement() {
		throw new NoSuchElementException();
	}

	@Override @NotNull
	public String toString() {
		return "EmptyEnumeration";
	}

}
